# TorrentFileQt

![torrentfileQt.png](./assets/torrentfileQt.png)

-------
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/065ca999772a434ba1aadae05f8b6bc7)](https://www.codacy.com/gh/alexpdev/torrentfileQt/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=alexpdev/torrentfileQt&amp;utm_campaign=Badge_Grade)
[![Codacy Badge](https://app.codacy.com/project/badge/Coverage/065ca999772a434ba1aadae05f8b6bc7)](https://www.codacy.com/gh/alexpdev/torrentfileQt/dashboard?utm_source=github.com&utm_medium=referral&utm_content=alexpdev/torrentfileQt&utm_campaign=Badge_Coverage)
[![codecov](https://codecov.io/gh/alexpdev/torrentfileQt/branch/main/graph/badge.svg?token=S5Q9CRD6C2)](https://codecov.io/gh/alexpdev/torrentfileQt)
![PyPI - Downloads](https://img.shields.io/pypi/dw/torrentfileQt?style=plastic)
![PyPI - License](https://img.shields.io/pypi/l/torrentfileQt?color=orange&style=plastic)

TorrentFileQt is a GUI Frontend for [TorrentFile CLI](https://github.com/alexpdev/torrentfile) project.

## Features

- Create .torrent files
- Display detailed information for a .torrent file
- Bittorrent v1, v2 and hybrid .torrent files supported
- Check if a .torrent file contents are in filesystem
- Check progress or percentage complete for .torrent file
- Edit torrent files.

### Screenshots

![createTab.png](./assets/createTab.png)

-------

![checkTab.png](./assets/checkTab.png)

-------

![infoTab.png](./assets/infoTab.png)

-------

![infoTab.png](./assets/editorTab.png)
